==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.net.ssl.config.impl/src/com/openexchange/net/ssl/config/impl/jslob/UserCanManageOwnCertificatesJSLobEntry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.net.ssl.config.impl.jslob;

import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.jslob.JSlobEntry;
import com.openexchange.jslob.JSlobKeys;
import com.openexchange.net.ssl.config.UserAwareSSLConfigurationService;
import com.openexchange.session.Session;

/**
 * {@link UserCanManageOwnCertificatesJSLobEntry}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class UserCanManageOwnCertificatesJSLobEntry implements JSlobEntry {

    private static final String LOB_NAMESPACE = "security";
    private static final String LOB_PATH = LOB_NAMESPACE + "/manageCertificates";

    private final UserAwareSSLConfigurationService userAwareSSLConfigurationService;

    /**
     * Initialises a new {@link UserCanManageOwnCertificatesJSLobEntry}.
     */
    public UserCanManageOwnCertificatesJSLobEntry(UserAwareSSLConfigurationService userAwareSSLConfigurationService) {
        super();
        this.userAwareSSLConfigurationService = userAwareSSLConfigurationService;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.jslob.JSlobEntry#getKey()
     */
    @Override
    public String getKey() {
        return JSlobKeys.CORE;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.jslob.JSlobEntry#getPath()
     */
    @Override
    public String getPath() {
        return LOB_PATH;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.jslob.JSlobEntry#isWritable(com.openexchange.session.Session)
     */
    @Override
    public boolean isWritable(Session session) throws OXException {
        return false;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.jslob.JSlobEntry#getValue(com.openexchange.session.Session)
     */
    @Override
    public Object getValue(Session session) throws OXException {
        return userAwareSSLConfigurationService.canManageCertificates(session.getUserId(), session.getContextId());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.jslob.JSlobEntry#setValue(java.lang.Object, com.openexchange.session.Session)
     */
    @Override
    public void setValue(Object value, Session sessiond) throws OXException {
        // no-op, read-only
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.jslob.JSlobEntry#metadata(com.openexchange.session.Session)
     */
    @Override
    public Map<String, Object> metadata(Session session) throws OXException {
        // no-op
        return null;
    }
}

==> open-xchange-core_7.10.3.orig.tar.bz2: open-xchange-core-7.10.3/com.openexchange.net.ssl.config.impl/src/com/openexchange/net/ssl/config/impl/jslob/UserCanManageOwnCertificatesJSLobEntry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.net.ssl.config.impl.jslob;

import static com.openexchange.java.Autoboxing.B;
import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.jslob.JSlobEntry;
import com.openexchange.jslob.JSlobKeys;
import com.openexchange.net.ssl.config.UserAwareSSLConfigurationService;
import com.openexchange.session.Session;

/**
 * {@link UserCanManageOwnCertificatesJSLobEntry}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class UserCanManageOwnCertificatesJSLobEntry implements JSlobEntry {

    private static final String LOB_NAMESPACE = "security";
    private static final String LOB_PATH = LOB_NAMESPACE + "/manageCertificates";

    private final UserAwareSSLConfigurationService userAwareSSLConfigurationService;

    /**
     * Initialises a new {@link UserCanManageOwnCertificatesJSLobEntry}.
     */
    public UserCanManageOwnCertificatesJSLobEntry(UserAwareSSLConfigurationService userAwareSSLConfigurationService) {
        super();
        this.userAwareSSLConfigurationService = userAwareSSLConfigurationService;
    }

    @Override
    public String getKey() {
        return JSlobKeys.CORE;
    }

    @Override
    public String getPath() {
        return LOB_PATH;
    }

    @Override
    public boolean isWritable(Session session) throws OXException {
        return false;
    }

    @Override
    public Object getValue(Session session) throws OXException {
        return B(userAwareSSLConfigurationService.canManageCertificates(session.getUserId(), session.getContextId()));
    }

    @Override
    public void setValue(Object value, Session sessiond) throws OXException {
        // no-op, read-only
    }

    @Override
    public Map<String, Object> metadata(Session session) throws OXException {
        // no-op
        return null;
    }
}
